/**
 * Classe Renderer2D, junto com a classe JanelaExemploJava2D, mostra um exemplo de 
 * como trabalhar com Java e OpenGL utilizando a API JOGL.  aberta uma 
 * janela na qual  desenhado um tringulo.
 * 
 * @author Isabel H. Manssour e Marcelo Cohen  
 * @version 1.0
 */

import java.awt.event.*; 
import javax.media.opengl.*;
import javax.media.opengl.glu.*;

public class Renderer2D extends KeyAdapter implements GLEventListener
{
	// Atributos
	private GL gl;
	private GLU glu;
	private GLAutoDrawable glDrawable;

	/**
	 * Mtodo definido na interface GLEventListener e chamado pelo objeto no qual ser feito o desenho
	 * logo aps a inicializao do contexto OpenGL. 
	 */    
	public void init(GLAutoDrawable drawable)
	{
		glDrawable = drawable;
		gl = drawable.getGL();     
		glu = new GLU();

		drawable.setGL(new DebugGL(gl));        

		gl.glClearColor(1.0f, 1.0f, 1.0f, 1.0f);
		
		// Define a janela de visualizao 2D
		gl.glMatrixMode(GL.GL_PROJECTION);
		glu.gluOrtho2D(-1.0,1.0,-1.0,1.0);
		gl.glMatrixMode(GL.GL_MODELVIEW);
	}

	/**
	 * Mtodo definido na interface GLEventListener e chamado pelo objeto no qual ser feito o desenho
	 * para comear a fazer o desenho OpenGL pelo cliente.
	 */  
	public void display(GLAutoDrawable drawable)
	{
		gl.glClear(GL.GL_COLOR_BUFFER_BIT);
		gl.glLoadIdentity();    

		gl.glColor3f(0.0f, 0.0f, 1.0f);

		// Desenha um tringulo no centro da janela
		gl.glBegin(GL.GL_TRIANGLES);
			gl.glVertex3d(-0.5,-0.5, 0.0);
			gl.glVertex3d( 0.0, 0.5, 0.0);
			gl.glVertex3d( 0.5,-0.5, 0.0);
		gl.glEnd();                 
	}

	/**
	 * Mtodo definido na interface GLEventListener e chamado pelo objeto no qual ser feito o desenho
	 * depois que a janela foi redimensionada.
	 */  
	public void reshape(GLAutoDrawable drawable, int x, int y, int width, int height)
	{
		gl.glViewport(0, 0, width, height);      
	}

	/**
	 * Mtodo definido na interface GLEventListener e chamado pelo objeto no qual ser feito o desenho
	 * quando o modo de exibio ou o dispositivo de exibio associado foi alterado.
	 */  
	public void displayChanged(GLAutoDrawable drawable, boolean modeChanged, boolean deviceChanged) { }

	/**
	 * Mtodo definido na interface KeyListener que est sendo implementado que seja 
	 * feita a sada do sistema quando for pressionada a tecla ESC.
	 */        
	public void keyPressed(KeyEvent e)
	{
		switch (e.getKeyCode())
		{
			case KeyEvent.VK_ESCAPE:	System.exit(0);
										break;
		}  
		glDrawable.display();
	}

}

